==> sharyn-11.13.1.tgz: package/components/LoadingPage.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime-corejs2/helpers/interopRequireDefault");

var _Object$defineProperty = require("@babel/runtime-corejs2/core-js/object/define-property");

_Object$defineProperty(exports, "__esModule", {
  value: true
});

exports["default"] = void 0;

var _extends2 = _interopRequireDefault(require("@babel/runtime-corejs2/helpers/extends"));

var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime-corejs2/helpers/objectWithoutProperties"));

var _react = _interopRequireDefault(require("react"));

var _util = require("@sharyn/css/util");

var _CircularProgress = _interopRequireDefault(require("@material-ui/core/CircularProgress"));

var _withStyles = _interopRequireDefault(require("@material-ui/core/styles/withStyles"));

var _DelayedProgress = _interopRequireDefault(require("./DelayedProgress"));

var _propTypes = _interopRequireDefault(require("prop-types"));

/* eslint-disable import/no-extraneous-dependencies */
// flow-disable-next-line
var LoadingPageJSX = function LoadingPageJSX(_ref) {
  var css = _ref.classes,
      noDelay = _ref.noDelay,
      rest = (0, _objectWithoutProperties2["default"])(_ref, ["classes", "noDelay"]);
  return _react["default"].createElement("div", (0, _extends2["default"])({
    className: css.middle
  }, rest), noDelay ? _react["default"].createElement(_CircularProgress["default"], {
    thickness: 4,
    size: 70
  }) : _react["default"].createElement(_DelayedProgress["default"], {
    thickness: 4,
    size: 70
  }));
};

LoadingPageJSX.propTypes = {
  classes: _propTypes["default"].object.isRequired,
  noDelay: _propTypes["default"].bool
};
var LoadingPage = (0, _withStyles["default"])({
  middle: _util.middle
})(LoadingPageJSX);
var _default = LoadingPage;
exports["default"] = _default;

==> sharyn-11.13.2.tgz: package/components/LoadingPage.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime-corejs2/helpers/interopRequireDefault");

var _Object$defineProperty = require("@babel/runtime-corejs2/core-js/object/define-property");

_Object$defineProperty(exports, "__esModule", {
  value: true
});

exports["default"] = void 0;

var _react = _interopRequireDefault(require("react"));

var _util = require("@sharyn/css/util");

var _CircularProgress = _interopRequireDefault(require("@material-ui/core/CircularProgress"));

var _withStyles = _interopRequireDefault(require("@material-ui/core/styles/withStyles"));

var _DelayedProgress = _interopRequireDefault(require("./DelayedProgress"));

var _propTypes = _interopRequireDefault(require("prop-types"));

/* eslint-disable import/no-extraneous-dependencies */
// flow-disable-next-line
var LoadingPageJSX = function LoadingPageJSX(_ref) {
  var css = _ref.classes,
      noDelay = _ref.noDelay;
  return _react["default"].createElement("div", {
    className: css.middle,
    "data-testid": "loading-page"
  }, noDelay ? _react["default"].createElement(_CircularProgress["default"], {
    thickness: 4,
    size: 70
  }) : _react["default"].createElement(_DelayedProgress["default"], {
    thickness: 4,
    size: 70
  }));
};

LoadingPageJSX.propTypes = {
  classes: _propTypes["default"].object.isRequired,
  noDelay: _propTypes["default"].bool
};
var LoadingPage = (0, _withStyles["default"])({
  middle: _util.middle
})(LoadingPageJSX);
var _default = LoadingPage;
exports["default"] = _default;
